@@ -29,24 +29,26 @@
 #'   + Named square matrix: computes standard errors with a user-supplied variance-covariance matrix. This matrix must be square and have dimensions equal to the number of coefficients in `get_coef(model)`.
 #' @param newdata A dataset over which to compute marginal effects. `NULL` uses
 #'   the original data used to fit the model.
-#' @param type Type(s) of prediction as string or vector This can
-#' differ based on the model type, but will typically be a string such as:
-#' "response", "link", "probs", or "zero".
-#' @param ... Additional arguments are pushed forward to `predict()`.
+#' @param type Type(s) of prediction as string or character vector. This can
+#'   differ based on the model type, but will typically be a string such as:
+#'   "response", "link", "probs", or "zero".
+#' @param ... The "Model-Specific Arguments" section below gives a list of arguments which can modify the behavior of this function for certain models (e.g., mixed-effects or bayesian).
+#'
+#' @template model_specific_arguments
+#'
 #' @return A `data.frame` with one row per observation (per term/group) and several columns:
 #' * `rowid`: row number of the `newdata` data frame
 #' * `type`: prediction type, as defined by the `type` argument
 #' * `group`: (optional) value of the grouped outcome (e.g., categorical outcome models)
 #' * `term`: the variable whose marginal effect is computed
 #' * `dydx`: marginal effect of the term on the outcome for a given combination of regressor values
-#' * `std.error`: standard errors computed by via the delta method. 
-#' @export
+#' * `std.error`: standard errors computed by via the delta method.
 #' @examples
 #'
 #' mod <- glm(am ~ hp * wt, data = mtcars, family = binomial)
 #' mfx <- marginaleffects(mod)
 #' head(mfx)
-
+#'
 #' # Average Marginal Effect (AME)
 #' summary(mfx)
 #' tidy(mfx)
@@ -72,6 +74,7 @@
 #' # Heteroskedasticity robust standard errors
 #' marginaleffects(mod, vcov = sandwich::vcovHC(mod))
 #'
+#' @export
 marginaleffects <- function(model,
                             newdata = NULL,
                             variables = NULL,
@@ -106,13 +109,8 @@ marginaleffects <- function(model,
     attributes_newdata <- attributes_newdata[idx]
 
     # sanity checks and pre-processing
-    model <- sanity_model(model = model,
-                          newdata = newdata,
-                          variables = variables,
-                          vcov = vcov,
-                          type = type,
-                          return_data = return_data,
-                          ...)
+    model <- sanity_model(model = model, ...)
+    sanity_dots(model = model, ...)
     sanity_type(model = model, type = type, calling_function = "marginaleffects")
     newdata <- sanity_newdata(model, newdata)
     variables <- sanity_variables(model, newdata, variables)
@@ -157,7 +155,8 @@ marginaleffects <- function(model,
                                             FUN = standard_errors_delta_marginaleffects,
                                             newdata = newdata,
                                             index = idx,
-                                            variable = v)
+                                            variable = v,
+                                            ...)
                 mfx$std.error <- as.numeric(se)
                 J <- attr(se, "J")
                 J_mean <- attr(se, "J_mean")
@@ -174,7 +173,21 @@ marginaleffects <- function(model,
     out <- bind_rows(mfx_list)
 
     J <- do.call("rbind", J_list) # bind_rows does not work for matrices
+
+    # duplicate colnames can occur for grouped outcome models, so we can't just
+    # use `poorman::bind_rows()`. Instead, ugly hack to make colnames unique
+    # with a weird string.
+    for (i in seq_along(J_mean_list)) {
+        if (inherits(J_mean_list[[i]], "data.frame")) {
+            newnames <- make.unique(names(J_mean_list[[i]]), sep = "______")
+            J_mean_list[[i]] <- stats::setNames(J_mean_list[[i]], newnames)
+        }
+    }
     J_mean <- bind_rows(J_mean_list) # bind_rows need because some have contrast col
+    if (inherits(J_mean, "data.frame")) {
+        J_mean <- stats::setNames(J_mean, gsub("______.*$", "", colnames(J_mean)))
+    }
+
 
     # empty contrasts equal "". important for merging in `tidy()`
     if ("contrast" %in% colnames(J_mean)) {
