@@ -6,7 +6,7 @@ test_that("lm quadratic", {
     dat <- data.frame(x = rnorm(N))
     dat$y <- 1 + 1 * dat$x + 1 * dat$x^2 + rnorm(N)
     mod <- lm(f, dat)
-    nd <- typical(newdata = dat, x = c(-2:2))
+    nd <- datagrid(newdata = dat, x = c(-2:2))
     res <- marginaleffects(mod, newdata = nd)
     res$truth <- truth(res$x)
     expect_equal(res$dydx, res$truth, tolerance = .01)
@@ -21,7 +21,7 @@ test_that("lm log", {
     dat <- data.frame(x = runif(N))
     dat$y <- log(dat$x) + rnorm(N)
     mod <- lm(f, dat)
-    nd <- typical(newdata = dat, x = c(1:4))
+    nd <- datagrid(newdata = dat, x = c(1:4))
     res <- marginaleffects(mod, newdata = nd)
     res$truth <- truth(res$x)
     expect_equal(res$dydx, res$truth, tolerance = .01)
@@ -38,7 +38,7 @@ test_that("logit", {
     dat <- data.frame(x = rnorm(N, sd = 3))
     dat$y <- rbinom(N, 1, pr = plogis(beta0 + beta1 * dat$x))
     mod <- glm(f, data = dat, family = binomial)
-    nd <- typical(newdata = dat, x = c(-10:10))
+    nd <- datagrid(newdata = dat, x = c(-10:10))
     res <- marginaleffects(mod, newdata = nd)
     res$truth <- truth(res$x)
     expect_equal(res$dydx, res$truth, tolerance = .01)
